@@ -2,8 +2,14 @@
 
 from functools import partial
 from contextlib import contextmanager
+import re
 import sys
 
+
+# compact 3.*
+if 'basestring' not in __builtins__:
+    basestring = str
+
 _just_chains = {
     'should': None, 'have': 'have', 'an': None, 'of': None,
     'a': None, 'be': 'be', 'also': None
@@ -30,7 +36,8 @@ _assertions = {
     'endswith': lambda exp, actual: actual.endswith(exp),
     'length': lambda exp, actual: len(actual) == exp,
     'key': lambda exp, actual: exp in actual.keys(),
-    'instanceof': lambda exp, actual: isinstance(actual, exp)
+    'instanceof': lambda exp, actual: isinstance(actual, exp),
+    'match': lambda exp, actual: re.match(exp, actual) is not None
 }
 
 
@@ -38,7 +45,7 @@ class _Should(object):
 
     def __init__(self, val=None):
         self._val = val
-        self._conj = 'be'
+        self._conj = ''
         self._not = False  # `not` flag
 
         self._set_property(_just_chains, self._chain)
@@ -58,11 +65,20 @@ class _Should(object):
             setattr(self, assertion, p)
 
     def throw(self, exception):
-        msg = ('should {0}raise ' + exception.__name__).format
+        if isinstance(exception, basestring):
+            exe_msg = exception
+            exception = Exception
+            msg = ('should {0}raise msg:' + exe_msg).format
+        else:
+            exe_msg = None
+            msg = ('should {0}raise ' + exception.__name__).format
+
         try:
             self._val()
-        except exception:
+        except exception as e:
             res = True
+            if exe_msg is not None:
+                res = exe_msg in str(e)
         else:
             res = False
         if self._not:
@@ -93,12 +109,12 @@ class _Should(object):
             setattr(cls, name, p)
 
     def _set_not(self, conj=None, cls=None):
-        self._conj = 'be' if conj is None else conj
+        self._conj = self._conj if conj is None else conj
         self._not = True
         return self
 
     def _chain(self, conj='be', cls=None):
-        self._conj = 'be' if conj is None else conj
+        self._conj = self._conj if conj is None else conj
         return self
 
     @property
@@ -122,11 +138,11 @@ class _Should(object):
 
     def _assertions(self, assertion, exp):
         res = _assertions[assertion](exp, self._val)
-        msg = '{0} should {1}{2} {3} {4}'.format
+        msg_format = '{0} should {1}{2} {3} {4}'.format
         if self._not:
             res = not res
-        self._assert(
-            res, msg(self._val, self._flag, self._conj, assertion, exp))
+        msg = msg_format(self._val, self._flag, self._conj, assertion, exp)
+        self._assert(res, msg)
         return self
 
     @property
@@ -135,21 +151,26 @@ class _Should(object):
         self._assert(res, msg)
         return self
 
+    @property
+    def empty(self):
+        self.length(0)
+        return self
+
     def __values(self, exp, actual):
         res = (actual is not exp) if self._not else (actual is exp)
-        msg = '{0} should be {1}{2}'.format
-        return res, msg(actual, self._flag, exp)
+        msg_format = '{0} should be {1}{2}'.format
+        return res, msg_format(actual, self._flag, exp)
 
     def __types(self, exp, value):
         actual = type(value)
         res = (actual is not exp) if self._not else (actual is exp)
-        msg = '{0} should be {1}{2}'.format
-        return res, msg(value, self._flag, exp)
+        msg_format = '{0} should be {1}{2}'.format
+        return res, msg_format(value, self._flag, exp)
 
     def _ok(self, actual):
         res = not bool(actual) if self._not else bool(actual)
-        msg = '{0}\'s bool value is {1}True'.format
-        return res, msg(actual, self._flag)
+        msg_format = '{0}\'s bool value is {1}True'.format
+        return res, msg_format(actual, self._flag)
 
 
 should = _Should
